function [sigTbl, SigEnd] = saving_data(IDtag, db, Data, change_file, Fs)
% funkce uloží data z SPI do daného souboru
%
% IDtag = 1x1, kód myši, která se má uložit, (integer)
%
% db = tabulka z databáze s informacemi
%
% Data = NxM, Data z daného SPI, N = počet elektrod, M = počet hodnot na
% jednu elektrodu, (integer)
%
% change_file = 1x1, číslo příštího souboru, (integer)
%
% Fs = 1x1, vzorkovací frekvence (integer)
%
%
% sigTbl = NxL, tabulka s daty pro uložení, L = [Subject, ChName, SigStart, SigEnd, Fs, M]
%
% SigEnd = 1x1, čas ukončení pro daný soubor, (datetime)
%
    dim = [];
    old = int2str(change_file-1);
    Data = single(Data);
    [Subject, elektrody, ~, ~, ~, ~, ~] = read_db(IDtag, db);
    pocet_vzorku = length(Data(1,:));
    sekundy = pocet_vzorku/Fs(1);
    h = 0;
    m = 0;
    du = duration(h,m,sekundy);
    foldername = Subject(1);
    filename = Subject(1);
    path = join(['C:\Users\HP\Documents\MATLAB\BC', foldername, filename], '\');
    path = join([path, '_', old, '.mat'],"");
    struct = open(path);
    sigTbl = struct.sigTbl;
    for i = 0:(length(elektrody)-1)
        sigTbl.SigEnd(end-i) = sigTbl.SigEnd(end-i) + du;
        dim = [dim 1];
    end
    SigEnd = sigTbl.SigEnd(1);
    if isa(sigTbl.Data, "cell")
        sigTbl.Data = cell2mat(sigTbl.Data);
    end
    sigTbl.Data = [sigTbl.Data Data];
    sigTbl.Data = mat2cell(sigTbl.Data, dim);
    save([pwd '\' char(Subject(1)) '\'  char(Subject(1)) '_' old '.mat'],'sigTbl')
end